## -*- coding: utf-8 -*-

__author__ = "gael@pilotsystems.net"
__format__ = "plaintext"
__version__ = "$Id: SharedQueue.py 8 2007-11-29 15:57:25Z gael.le-mignot $"

import threading

def synchronised(func):
    def inner(self, *args, **kwargs):
        self.lock.acquire()
        try:
            return func(self, *args, **kwargs)
        finally:
            self.lock.release()
    return inner

class SharedQueue(object):
    """
    A queue that is thread-safe
    """
    def __init__(self):
        self.lock = threading.RLock()
        self.items = []

    @synchronised
    def append(self, item):
        self.items.append(item)

    @synchronised
    def pop(self):
        if not self.items:
            return None
        return self.items.pop()

                
