# -*- coding: utf-8 -*-

from AccessControl import getSecurityManager
from AccessControl.SecurityManagement import newSecurityManager, setSecurityManager
from AccessControl.User import UnrestrictedUser as BaseUnrestrictedUser


class UnrestrictedUser(BaseUnrestrictedUser):
    """Unrestricted user that still has an id."""
    def getId(self):
        """Return the ID of the user."""
        return self.getUserName()
        
def run_as_user(user, callback, *args, **kwargs):
    """
    Run the given function as given user
    
    user must be a user object
    """
    old_sm = getSecurityManager()
    try:
        newSecurityManager(None, user)
        return callback(*args, **kwargs)
    finally:
        setSecurityManager(old_sm)

def run_as_manager(self, callback, *args, **kwargs):
    """
    Run the given function as a manager user
    
    self must be an acquisition context able to locate acl_users
    """
    # Create Manager security context
    tmp_user = UnrestrictedUser('manager', '', ['Manager', 'Owner'], '')
    tmp_user = tmp_user.__of__(self.acl_users)
    return run_as_user(tmp_user, callback, *args, **kwargs)


